=== modified file 'drizzled/common.h'
--- drizzled/common.h	2010-12-18 02:08:04 +0000
+++ drizzled/common.h	2010-12-24 06:48:40 +0000
@@ -191,6 +191,7 @@
                         DRIZZLE_TYPE_ENUM,
                         DRIZZLE_TYPE_BLOB,
                         DRIZZLE_TYPE_TIME,
+                        DRIZZLE_TYPE_BOOLEAN,
                         DRIZZLE_TYPE_UUID
 };
 const int enum_field_types_size= DRIZZLE_TYPE_UUID + 1;

=== modified file 'drizzled/create_field.cc'
--- drizzled/create_field.cc	2010-12-20 21:16:48 +0000
+++ drizzled/create_field.cc	2010-12-24 06:48:40 +0000
@@ -31,6 +31,7 @@
 #include "drizzled/field/str.h"
 #include "drizzled/field/num.h"
 #include "drizzled/field/blob.h"
+#include "drizzled/field/boolean.h"
 #include "drizzled/field/enum.h"
 #include "drizzled/field/null.h"
 #include "drizzled/field/date.h"
@@ -356,6 +357,9 @@
     case DRIZZLE_TYPE_UUID:
       length= field::Uuid::max_string_length();
       break;
+    case DRIZZLE_TYPE_BOOLEAN:
+      length= field::Boolean::max_string_length();
+      break;
     case DRIZZLE_TYPE_DATETIME:
       length= DateTime::MAX_STRING_LENGTH;
       break;

=== modified file 'drizzled/definition/table.cc'
--- drizzled/definition/table.cc	2010-12-24 04:29:32 +0000
+++ drizzled/definition/table.cc	2010-12-24 16:11:53 +0000
@@ -64,6 +64,7 @@
 #include "drizzled/field/str.h"
 #include "drizzled/field/num.h"
 #include "drizzled/field/blob.h"
+#include "drizzled/field/boolean.h"
 #include "drizzled/field/enum.h"
 #include "drizzled/field/null.h"
 #include "drizzled/field/date.h"
@@ -270,6 +271,9 @@
   case message::Table::Field::UUID:
     field_type= DRIZZLE_TYPE_UUID;
     break;
+  case message::Table::Field::BOOLEAN:
+    field_type= DRIZZLE_TYPE_BOOLEAN;
+    break;
   case message::Table::Field::TIME:
     field_type= DRIZZLE_TYPE_TIME;
     break;
@@ -317,6 +321,7 @@
   case DRIZZLE_TYPE_DATE:
   case DRIZZLE_TYPE_ENUM:
   case DRIZZLE_TYPE_UUID:
+  case DRIZZLE_TYPE_BOOLEAN:
     default_item= new Item_string(default_value->c_str(),
                                   default_value->length(),
                                   system_charset_info);
@@ -1316,6 +1321,9 @@
     case DRIZZLE_TYPE_UUID:
       field_length= field::Uuid::max_string_length();
       break;
+    case DRIZZLE_TYPE_BOOLEAN:
+      field_length= field::Boolean::max_string_length();
+      break;
     case DRIZZLE_TYPE_TIMESTAMP:
       field_length= field::Epoch::max_string_length();
       break;
@@ -1326,7 +1334,7 @@
       abort(); // Programming error
     }
 
-    assert(enum_field_types_size == 13);
+    assert(enum_field_types_size == 14);
 
     Field* f= make_field(pfield,
                          record + field_offsets[fieldnr] + data_offset,
@@ -1359,6 +1367,7 @@
     case DRIZZLE_TYPE_LONGLONG:
     case DRIZZLE_TYPE_NULL:
     case DRIZZLE_TYPE_UUID:
+    case DRIZZLE_TYPE_BOOLEAN:
       break;
     }
 
@@ -2127,6 +2136,13 @@
                                        null_pos,
                                        null_bit,
                                        field_name);
+  case DRIZZLE_TYPE_BOOLEAN:
+    return new (&mem_root) field::Boolean(ptr,
+                                          field_length,
+                                          null_pos,
+                                          null_bit,
+                                          field_name,
+                                          is_unsigned);
   case DRIZZLE_TYPE_LONG:
     return new (&mem_root) field::Int32(ptr,
                                         field_length,

=== modified file 'drizzled/display.cc'
--- drizzled/display.cc	2010-12-24 00:35:17 +0000
+++ drizzled/display.cc	2010-12-24 16:11:53 +0000
@@ -52,6 +52,7 @@
 static const std::string DRIZZLE_TYPE_ENUM("DRIZZLE_TYPE_ENUM"); 
 static const std::string DRIZZLE_TYPE_BLOB("DRIZZLE_TYPE_BLOB"); 
 static const std::string DRIZZLE_TYPE_UUID("DRIZZLE_TYPE_UUID"); 
+static const std::string DRIZZLE_TYPE_BOOLEAN("DRIZZLE_TYPE_BOOLEAN"); 
 
 static const std::string FIELD_ITEM("FIELD_ITEM");
 static const std::string FUNC_ITEM("FUNC_ITEM");
@@ -227,6 +228,8 @@
     return DRIZZLE_TYPE_BLOB;
   case drizzled::DRIZZLE_TYPE_UUID : 
     return DRIZZLE_TYPE_UUID;
+  case drizzled::DRIZZLE_TYPE_BOOLEAN : 
+    return DRIZZLE_TYPE_BOOLEAN;
   }
 
   assert(0);

=== modified file 'drizzled/enum.h'
--- drizzled/enum.h	2010-12-24 07:53:15 +0000
+++ drizzled/enum.h	2010-12-24 16:11:53 +0000
@@ -1065,10 +1065,11 @@
   ER_CORRUPT_TABLE_DEFINITION_UNKNOWN_COLLATION,
   ER_INVALID_CAST_TO_SIGNED,
   ER_INVALID_CAST_TO_UNSIGNED,
+  ER_INVALID_BOOLEAN_VALUE,
 
-  // Leave UUID as LAST, and force people to use tags instead of numbers in
-  // error messages in test.
-  ER_ERROR_LAST= ER_INVALID_CAST_TO_UNSIGNED
+  // Leave ER_INVALID_BOOLEAN_VALUE as LAST, and force people to use tags
+  // instead of numbers in error messages in test.
+  ER_ERROR_LAST= ER_INVALID_BOOLEAN_VALUE
 };
 
 enum drizzle_exit_codes {

=== modified file 'drizzled/error.cc'
--- drizzled/error.cc	2010-12-24 07:53:15 +0000
+++ drizzled/error.cc	2010-12-24 16:11:53 +0000
@@ -509,6 +509,9 @@
   ADD_ERROR_MESSAGE(ER_INVALID_UUID_VALUE, N_("Received an invalid UUID value"));
   ADD_ERROR_MESSAGE(ER_INVALID_UUID_TIME, N_("The UUID was not created with a valid time"));
 
+  // For BOOL type
+  ADD_ERROR_MESSAGE(ER_INVALID_BOOLEAN_VALUE, N_("Received an invalid BOOLEAN value '%s'."));
+
   // Some old error values use the same strings as some new error values.
   ADD_ERROR_MESSAGE(EE_FILENOTFOUND, find(ER_FILE_NOT_FOUND));
   ADD_ERROR_MESSAGE(EE_CANTCREATEFILE, find(ER_CANT_CREATE_FILE));

=== modified file 'drizzled/field.cc'
--- drizzled/field.cc	2010-12-21 20:27:48 +0000
+++ drizzled/field.cc	2010-12-24 08:41:24 +0000
@@ -1,6 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
+ *  Copyright (C) 2010 Brian Aker
  *  Copyright (C) 2008 MySQL
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -31,6 +32,7 @@
 #include "drizzled/field/str.h"
 #include "drizzled/field/num.h"
 #include "drizzled/field/blob.h"
+#include "drizzled/field/boolean.h"
 #include "drizzled/field/enum.h"
 #include "drizzled/field/null.h"
 #include "drizzled/field/date.h"
@@ -86,6 +88,8 @@
     DRIZZLE_TYPE_BLOB,
     //DRIZZLE_TYPE_TIME
     DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
   },
@@ -115,6 +119,8 @@
     DRIZZLE_TYPE_BLOB,
     //DRIZZLE_TYPE_TIME
     DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
   },
@@ -144,6 +150,8 @@
     DRIZZLE_TYPE_BLOB,
     //DRIZZLE_TYPE_TIME
     DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_BOOLEAN,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_UUID,
   },
@@ -173,6 +181,8 @@
     DRIZZLE_TYPE_BLOB,
     //DRIZZLE_TYPE_TIME
     DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
   },
@@ -201,6 +211,8 @@
     DRIZZLE_TYPE_BLOB,
     //DRIZZLE_TYPE_TIME
     DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
   },
@@ -230,6 +242,8 @@
     DRIZZLE_TYPE_BLOB,
     //DRIZZLE_TYPE_TIME
     DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
   },
@@ -259,6 +273,8 @@
     DRIZZLE_TYPE_BLOB,
     //DRIZZLE_TYPE_TIME
     DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
   },
@@ -288,6 +304,8 @@
     DRIZZLE_TYPE_BLOB,
     //DRIZZLE_TYPE_TIME
     DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
   },
@@ -317,6 +335,8 @@
     DRIZZLE_TYPE_BLOB,
     //DRIZZLE_TYPE_TIME
     DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
   },
@@ -346,6 +366,8 @@
     DRIZZLE_TYPE_BLOB,
     //DRIZZLE_TYPE_TIME
     DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
    },
@@ -375,6 +397,8 @@
     DRIZZLE_TYPE_BLOB,
     //DRIZZLE_TYPE_TIME
     DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_VARCHAR,
   },
@@ -404,9 +428,42 @@
     DRIZZLE_TYPE_BLOB,
     //DRIZZLE_TYPE_TIME
     DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_UUID,
   },
+  /* DRIZZLE_TYPE_BOOLEAN -> */
+  {
+    //DRIZZLE_TYPE_LONG
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_DOUBLE
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_NULL
+    DRIZZLE_TYPE_BOOLEAN,
+    //DRIZZLE_TYPE_TIMESTAMP
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_LONGLONG
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_DATETIME
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_DATE
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_VARCHAR
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_DECIMAL
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_VARCHAR,
+    DRIZZLE_TYPE_VARCHAR,
+    //DRIZZLE_TYPE_BLOB
+    DRIZZLE_TYPE_BLOB,
+    //DRIZZLE_TYPE_TIME
+    DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_BOOLEAN,
+    //DRIZZLE_TYPE_UUID
+    DRIZZLE_TYPE_VARCHAR,
+  },
   /* DRIZZLE_TYPE_UUID -> */
   {
     //DRIZZLE_TYPE_LONG
@@ -433,6 +490,8 @@
     DRIZZLE_TYPE_BLOB,
     //DRIZZLE_TYPE_TIME
     DRIZZLE_TYPE_TIME,
+    //DRIZZLE_TYPE_BOOLEAN
+    DRIZZLE_TYPE_VARCHAR,
     //DRIZZLE_TYPE_UUID
     DRIZZLE_TYPE_UUID,
   },
@@ -464,6 +523,8 @@
   STRING_RESULT,
   //DRIZZLE_TYPE_TIME
   STRING_RESULT,
+  //DRIZZLE_TYPE_BOOLEAN
+  STRING_RESULT,
   //DRIZZLE_TYPE_UUID
   STRING_RESULT,
 };
@@ -1005,6 +1066,7 @@
   switch (type) {
   case DRIZZLE_TYPE_VARCHAR: return (length + (length < 256 ? 1: 2));
   case DRIZZLE_TYPE_UUID: return field::Uuid::max_string_length();
+  case DRIZZLE_TYPE_BOOLEAN: return field::Boolean::max_string_length();
   case DRIZZLE_TYPE_DATE:
   case DRIZZLE_TYPE_ENUM:
   case DRIZZLE_TYPE_LONG: return 4;

=== added file 'drizzled/field/boolean.cc'
--- drizzled/field/boolean.cc	1970-01-01 00:00:00 +0000
+++ drizzled/field/boolean.cc	2010-12-24 08:41:24 +0000
@@ -0,0 +1,229 @@
+/* - mode: c++ c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+
+#include "config.h"
+
+#include <algorithm>
+
+#include "drizzled/field/boolean.h"
+
+#include "drizzled/error.h"
+#include "drizzled/internal/my_sys.h"
+#include "drizzled/session.h"
+#include "drizzled/table.h"
+#include "drizzled/temporal.h"
+
+union set_true_t {
+  unsigned char byte;
+  bool is_true:1;
+
+  set_true_t()
+  {
+    is_true= true;
+  }
+} set_true;
+
+namespace drizzled
+{
+namespace field
+{
+
+Boolean::Boolean(unsigned char *ptr_arg,
+                 uint32_t len_arg,
+                 unsigned char *null_ptr_arg,
+                 unsigned char null_bit_arg,
+                 const char *field_name_arg,
+                 bool ansi_display_arg) :
+  Field(ptr_arg, len_arg,
+        null_ptr_arg,
+        null_bit_arg,
+        Field::NONE,
+        field_name_arg),
+  ansi_display(ansi_display_arg)
+  {
+  }
+
+int Boolean::cmp(const unsigned char *a, const unsigned char *b)
+{ 
+  return memcmp(a, b, sizeof(unsigned char));
+}
+
+int Boolean::store(const char *from, uint32_t length, const CHARSET_INFO * const )
+{
+  ASSERT_COLUMN_MARKED_FOR_WRITE;
+
+  if (length == 1)
+  {
+    switch (from[0])
+    {
+    case 'y': case 'Y':
+    case 't': case 'T': // PG compatibility
+      setTrue();
+      return 0;
+
+    case 'n': case 'N':
+    case 'f': case 'F': // PG compatibility
+      setFalse();
+      return 0;
+
+    default:
+      my_error(ER_INVALID_BOOLEAN_VALUE, MYF(0), from);
+      return 1; // invalid
+    }
+  }
+  else if ((length == 5) and (strcasecmp(from, "FALSE") == 0))
+  {
+    setFalse();
+  }
+  if ((length == 4) and (strcasecmp(from, "TRUE") == 0))
+  {
+    setTrue();
+  }
+  else if ((length == 5) and (strcasecmp(from, "FALSE") == 0))
+  {
+    setFalse();
+  }
+  else if ((length == 3) and (strcasecmp(from, "YES") == 0))
+  {
+    setTrue();
+  }
+  else if ((length == 2) and (strcasecmp(from, "NO") == 0))
+  {
+    setFalse();
+  }
+  else
+  {
+    my_error(ER_INVALID_BOOLEAN_VALUE, MYF(0), from);
+    return 1; // invalid
+  }
+
+  return 0;
+}
+
+int Boolean::store(int64_t nr, bool )
+{
+  ASSERT_COLUMN_MARKED_FOR_WRITE;
+  nr == 0 ? setFalse() : setTrue();
+  return 0;
+}
+
+int  Boolean::store(double nr)
+{
+  ASSERT_COLUMN_MARKED_FOR_WRITE;
+  nr == 0 ? setFalse() : setTrue();
+  return 0;
+}
+
+int Boolean::store_decimal(const drizzled::my_decimal *dec)
+{
+  ASSERT_COLUMN_MARKED_FOR_WRITE;
+  if (my_decimal_is_zero(dec))
+  {
+    setFalse();
+    return 0;
+  }
+
+  setTrue();
+
+  return 0;
+}
+
+void Boolean::sql_type(String &res) const
+{
+  res.set_ascii(STRING_WITH_LEN("boolean"));
+}
+
+double Boolean::val_real()
+{
+  ASSERT_COLUMN_MARKED_FOR_READ;
+  return isTrue();
+}
+
+int64_t Boolean::val_int()
+{
+  ASSERT_COLUMN_MARKED_FOR_READ;
+  return isTrue();
+}
+
+String *Boolean::val_str(String *val_buffer, String *)
+{
+  ASSERT_COLUMN_MARKED_FOR_READ;
+  const CHARSET_INFO * const cs= &my_charset_bin;
+  uint32_t mlength= (5) * cs->mbmaxlen;
+
+  val_buffer->alloc(mlength);
+  char *buffer=(char*) val_buffer->ptr();
+
+  if (isTrue())
+  {
+    if (ansi_display)
+    {
+      memcpy(buffer, "YES", 3);
+      val_buffer->length(3);
+    }
+    else
+    {
+      memcpy(buffer, "TRUE", 4);
+      val_buffer->length(4);
+    }
+  }
+  else
+  {
+    if (ansi_display)
+    {
+      memcpy(buffer, "NO", 2);
+      val_buffer->length(2);
+    }
+    else
+    {
+      memcpy(buffer, "FALSE", 5);
+      val_buffer->length(5);
+    }
+  }
+
+  return val_buffer;
+}
+
+my_decimal *Boolean::val_decimal(my_decimal *dec)
+{
+  if (isTrue())
+  {
+    int2my_decimal(E_DEC_OK, 1, false, dec);
+    return dec;
+  }
+
+  my_decimal_set_zero(dec);
+
+  return dec;
+}
+
+void Boolean::sort_string(unsigned char *to, uint32_t length_arg)
+{
+  memcpy(to, ptr, length_arg);
+}
+
+void Boolean::setTrue()
+{
+  ptr[0]= set_true.byte;
+}
+
+} /* namespace field */
+} /* namespace drizzled */

=== added file 'drizzled/field/boolean.h'
--- drizzled/field/boolean.h	1970-01-01 00:00:00 +0000
+++ drizzled/field/boolean.h	2010-12-24 08:41:24 +0000
@@ -0,0 +1,93 @@
+/* - mode: c++ c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_FIELD_BOOLEAN_H
+#define DRIZZLED_FIELD_BOOLEAN_H
+
+#include <drizzled/field.h>
+#include <string>
+
+namespace drizzled
+{
+namespace field
+{
+
+class Boolean :public Field {
+  bool ansi_display;
+
+public:
+  Boolean(unsigned char *ptr_arg,
+          uint32_t len_arg,
+          unsigned char *null_ptr_arg,
+          unsigned char null_bit_arg,
+          const char *field_name_arg,
+          bool ansi_display= false);
+
+  enum_field_types type() const { return DRIZZLE_TYPE_BOOLEAN; }
+  enum ha_base_keytype key_type() const { return HA_KEYTYPE_BINARY; }
+  bool zero_pack() const { return 0; }
+  int  reset(void) { ptr[0]= 0; return 0; }
+  uint32_t pack_length() const { return sizeof(unsigned char); }
+  uint32_t key_length() const { return sizeof(unsigned char); }
+
+  int store(const char *to, uint32_t length, const CHARSET_INFO * const charset);
+  int store(double );
+  int store(int64_t nr, bool unsigned_val);
+  int store_decimal(const drizzled::my_decimal*);
+
+  String *val_str(String*,String *);
+  double val_real();
+  int64_t val_int();
+  my_decimal *val_decimal(my_decimal *);
+
+  void sql_type(drizzled::String&) const;
+
+  Item_result result_type () const { return STRING_RESULT; }
+  int cmp(const unsigned char*, const unsigned char*);
+  void sort_string(unsigned char*, uint32_t);
+  uint32_t max_display_length() { return 5; } // longest string is "false"
+
+  inline String *val_str(String *str) { return val_str(str, str); }
+  uint32_t size_of() const { return sizeof(*this); }
+
+  static size_t max_string_length()
+  {
+    return sizeof(unsigned char);
+  }
+
+private:
+  void setTrue();
+
+  void setFalse()
+  {
+    ptr[0]= 0;
+  }
+
+  bool isTrue() const
+  {
+    return ptr[0] ? true : false;
+  }
+};
+
+} /* namespace field */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_FIELD_BOOLEAN_H */
+

=== modified file 'drizzled/include.am'
--- drizzled/include.am	2010-12-24 03:44:02 +0000
+++ drizzled/include.am	2010-12-24 16:11:53 +0000
@@ -80,6 +80,7 @@
 			      drizzled/execute.h \
 			      drizzled/field.h \
 			      drizzled/field/blob.h \
+			      drizzled/field/boolean.h \
 			      drizzled/field/date.h \
 			      drizzled/field/datetime.h \
 			      drizzled/field/decimal.h \
@@ -94,9 +95,9 @@
 			      drizzled/field/size.h \
 			      drizzled/field/str.h \
 			      drizzled/field/time.h \
-			      drizzled/field/varstring.h \
 			      drizzled/field/uuid.h \
 			      drizzled/field/uuid_st.h \
+			      drizzled/field/varstring.h \
 			      drizzled/field_iterator.h \
 			      drizzled/file_exchange.h \
 			      drizzled/filesort.h \
@@ -510,6 +511,7 @@
 			   drizzled/execute.cc \
 			   drizzled/field.cc \
 			   drizzled/field/blob.cc \
+			   drizzled/field/boolean.cc \
 			   drizzled/field/date.cc \
 			   drizzled/field/datetime.cc \
 			   drizzled/field/decimal.cc \

=== modified file 'drizzled/item.cc'
--- drizzled/item.cc	2010-12-24 03:44:02 +0000
+++ drizzled/item.cc	2010-12-24 16:11:53 +0000
@@ -1076,6 +1076,7 @@
     case DRIZZLE_TYPE_LONGLONG:
     case DRIZZLE_TYPE_NULL:
     case DRIZZLE_TYPE_UUID:
+    case DRIZZLE_TYPE_BOOLEAN:
       return false;
   }
 
@@ -1204,6 +1205,7 @@
   case DRIZZLE_TYPE_TIME:
     field= new field::Time(maybe_null, name, &my_charset_bin);
     break;
+  case DRIZZLE_TYPE_BOOLEAN:
   case DRIZZLE_TYPE_UUID:
   case DRIZZLE_TYPE_ENUM:
   case DRIZZLE_TYPE_VARCHAR:
@@ -1353,6 +1355,7 @@
   case DRIZZLE_TYPE_ENUM:
   case DRIZZLE_TYPE_BLOB:
   case DRIZZLE_TYPE_VARCHAR:
+  case DRIZZLE_TYPE_BOOLEAN:
   case DRIZZLE_TYPE_UUID:
   case DRIZZLE_TYPE_DECIMAL:
     {

=== modified file 'drizzled/message.cc'
--- drizzled/message.cc	2010-12-20 07:54:13 +0000
+++ drizzled/message.cc	2010-12-24 06:48:40 +0000
@@ -53,6 +53,7 @@
 static const std::string DATETIME("DATETIME");
 static const std::string TIME("TIME");
 static const std::string UUID("UUID");
+static const std::string BOOLEAN("BOOLEAN");
 
 static const std::string UNDEFINED("UNDEFINED");
 static const std::string RESTRICT("RESTRICT");
@@ -142,6 +143,7 @@
   case message::Table::Field::DATETIME:
   case message::Table::Field::TIME:
   case message::Table::Field::UUID:
+  case message::Table::Field::BOOLEAN:
     break;
   }
 
@@ -178,6 +180,8 @@
     return TIME;
   case message::Table::Field::UUID:
     return UUID;
+  case message::Table::Field::BOOLEAN:
+    return BOOLEAN;
   }
 
   abort();
@@ -211,6 +215,8 @@
     return TIME;
   case message::Table::Field::UUID:
     return UUID;
+  case message::Table::Field::BOOLEAN:
+    return BOOLEAN;
   }
 
   abort();

=== modified file 'drizzled/message/statement_transform.cc'
--- drizzled/message/statement_transform.cc	2010-12-23 18:45:30 +0000
+++ drizzled/message/statement_transform.cc	2010-12-24 16:11:53 +0000
@@ -1349,6 +1349,9 @@
   case Table::Field::UUID:
     destination.append(" UUID", 5);
     break;
+  case Table::Field::BOOLEAN:
+    destination.append(" BOOLEAN", 8);
+    break;
   case Table::Field::INTEGER:
     destination.append(" INT", 4);
     break;
@@ -1374,7 +1377,7 @@
     destination.append(" DATETIME",  9);
     break;
   case Table::Field::TIME:
-    destination.append(" TIME",  9);
+    destination.append(" TIME",  5);
     break;
   }
 
@@ -1510,6 +1513,8 @@
     return Table::Field::BLOB;
   case DRIZZLE_TYPE_UUID:
     return Table::Field::UUID;
+  case DRIZZLE_TYPE_BOOLEAN:
+    return Table::Field::BOOLEAN;
   }
 
   assert(false);

=== modified file 'drizzled/message/table.proto'
--- drizzled/message/table.proto	2010-12-19 23:15:38 +0000
+++ drizzled/message/table.proto	2010-12-24 06:48:40 +0000
@@ -78,6 +78,7 @@
       DATETIME = 10;
       UUID = 11;
       TIME = 12;
+      BOOLEAN = 13;
     }
 
     message FieldOptions {

=== modified file 'drizzled/plugin/table_function.cc'
--- drizzled/plugin/table_function.cc	2010-12-20 21:16:48 +0000
+++ drizzled/plugin/table_function.cc	2010-12-24 06:48:40 +0000
@@ -107,9 +107,6 @@
 
   switch (type) 
   {
-  default:
-  case TableFunction::BOOLEAN: // Currently BOOLEAN always has a value
-    field_length= 5;
   case TableFunction::STRING:
     {
       drizzled::message::Table::Field::StringFieldOptions *string_field_options;
@@ -146,6 +143,10 @@
     field->set_type(drizzled::message::Table::Field::BIGINT);
     field_constraints->set_is_unsigned(true);
     break;
+  case TableFunction::BOOLEAN: // Currently BOOLEAN always has a value
+    field->set_type(drizzled::message::Table::Field::BOOLEAN);
+    field_constraints->set_is_unsigned(true);
+    break;
   }
 }
 

=== modified file 'drizzled/sql_string.cc'
--- drizzled/sql_string.cc	2010-12-07 18:30:53 +0000
+++ drizzled/sql_string.cc	2010-12-24 05:50:22 +0000
@@ -819,6 +819,17 @@
   return str+ cs->cset->scan(cs, str, end, MY_SEQ_SPACES) == end;
 }
 
+std::ostream& operator<<(std::ostream& output, const String &str)
+{
+  output << "String:(";
+  output <<  const_cast<String&>(str).c_str();
+  output << ", ";
+  output << str.length();
+  output << ")";
+
+  return output;  // for multiple << operators.
+}
+
 } /* namespace drizzled */
 
 bool operator==(const drizzled::String &s1, const drizzled::String &s2)

=== modified file 'drizzled/sql_string.h'
--- drizzled/sql_string.h	2010-12-18 04:43:40 +0000
+++ drizzled/sql_string.h	2010-12-24 05:50:22 +0000
@@ -339,6 +339,8 @@
 bool check_if_only_end_space(const CHARSET_INFO * const cs, char *str,
                              char *end);
 
+std::ostream& operator<<(std::ostream& output, const String &str);
+
 } /* namespace drizzled */
 
 bool operator==(const drizzled::String &s1, const drizzled::String &s2);

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2010-12-24 09:17:43 +0000
+++ drizzled/sql_yacc.yy	2010-12-24 16:11:53 +0000
@@ -1733,6 +1733,26 @@
             if (statement->current_proto_field)
               statement->current_proto_field->set_type(message::Table::Field::UUID);
           }
+        | BOOL_SYM
+        {
+          $$=DRIZZLE_TYPE_BOOLEAN;
+
+          statement::CreateTable *statement=
+            (statement::CreateTable *)Lex->statement;
+
+          if (statement->current_proto_field)
+            statement->current_proto_field->set_type(message::Table::Field::BOOLEAN);
+        }
+        | BOOLEAN_SYM
+        {
+          $$=DRIZZLE_TYPE_BOOLEAN;
+
+          statement::CreateTable *statement=
+            (statement::CreateTable *)Lex->statement;
+
+          if (statement->current_proto_field)
+            statement->current_proto_field->set_type(message::Table::Field::BOOLEAN);
+        }
         | SERIAL_SYM
           {
             $$=DRIZZLE_TYPE_LONGLONG;

=== added file 'plugin/archive/tests/r/bool_type.result'
--- plugin/archive/tests/r/bool_type.result	1970-01-01 00:00:00 +0000
+++ plugin/archive/tests/r/bool_type.result	2010-12-24 06:48:40 +0000
@@ -0,0 +1,14 @@
+CREATE TABLE t1 (A BOOLEAN);
+insert into t1 VALUES ("no");
+insert into t1 VALUES ("false");
+insert into t1 VALUES ("true");
+insert into t1 VALUES ("yes");
+insert into t1 VALUES ("from");
+ERROR HY000: Received an invalid BOOLEAN value 'from'.
+SELECT A from t1 ORDER BY a;
+A
+FALSE
+FALSE
+TRUE
+TRUE
+DROP TABLE t1;

=== added file 'plugin/archive/tests/t/bool_type.test'
--- plugin/archive/tests/t/bool_type.test	1970-01-01 00:00:00 +0000
+++ plugin/archive/tests/t/bool_type.test	2010-12-24 06:48:40 +0000
@@ -0,0 +1,13 @@
+CREATE TABLE t1 (A BOOLEAN);
+insert into t1 VALUES ("no");
+insert into t1 VALUES ("false");
+
+insert into t1 VALUES ("true");
+insert into t1 VALUES ("yes");
+
+--error ER_INVALID_BOOLEAN_VALUE
+insert into t1 VALUES ("from");
+
+SELECT A from t1 ORDER BY a;
+
+DROP TABLE t1;

=== modified file 'plugin/collation_dictionary/tests/r/data_dictionary.result'
--- plugin/collation_dictionary/tests/r/data_dictionary.result	2010-09-02 18:35:05 +0000
+++ plugin/collation_dictionary/tests/r/data_dictionary.result	2010-12-24 08:41:24 +0000
@@ -14,8 +14,8 @@
   `COLLATION_NAME` VARCHAR(256) NOT NULL,
   `DESCRIPTION` VARCHAR(256) NOT NULL,
   `ID` BIGINT NOT NULL,
-  `IS_DEFAULT` VARCHAR(5) NOT NULL,
-  `IS_COMPILED` VARCHAR(5) NOT NULL,
+  `IS_DEFAULT` BOOLEAN NOT NULL,
+  `IS_COMPILED` BOOLEAN NOT NULL,
   `SORTLEN` BIGINT NOT NULL
 ) ENGINE=FunctionEngine COLLATE = utf8_general_ci
 SELECT * FROM character_sets ORDER BY CHARACTER_SET_NAME;

=== added file 'plugin/csv/tests/r/bool_type.result'
--- plugin/csv/tests/r/bool_type.result	1970-01-01 00:00:00 +0000
+++ plugin/csv/tests/r/bool_type.result	2010-12-24 06:48:40 +0000
@@ -0,0 +1,14 @@
+CREATE TABLE t1 (A BOOLEAN NOT NULL);
+insert into t1 VALUES ("no");
+insert into t1 VALUES ("false");
+insert into t1 VALUES ("true");
+insert into t1 VALUES ("yes");
+insert into t1 VALUES ("from");
+ERROR HY000: Received an invalid BOOLEAN value 'from'.
+SELECT A from t1 ORDER BY a;
+A
+FALSE
+FALSE
+TRUE
+TRUE
+DROP TABLE t1;

=== added file 'plugin/csv/tests/t/bool_type.test'
--- plugin/csv/tests/t/bool_type.test	1970-01-01 00:00:00 +0000
+++ plugin/csv/tests/t/bool_type.test	2010-12-24 06:48:40 +0000
@@ -0,0 +1,13 @@
+CREATE TABLE t1 (A BOOLEAN NOT NULL);
+insert into t1 VALUES ("no");
+insert into t1 VALUES ("false");
+
+insert into t1 VALUES ("true");
+insert into t1 VALUES ("yes");
+
+--error ER_INVALID_BOOLEAN_VALUE
+insert into t1 VALUES ("from");
+
+SELECT A from t1 ORDER BY a;
+
+DROP TABLE t1;

=== modified file 'plugin/information_schema_dictionary/tests/r/show_create_table.result'
--- plugin/information_schema_dictionary/tests/r/show_create_table.result	2010-12-20 07:54:13 +0000
+++ plugin/information_schema_dictionary/tests/r/show_create_table.result	2010-12-24 08:41:24 +0000
@@ -16,7 +16,7 @@
   `COLUMN_NAME` VARCHAR(256) NOT NULL,
   `ORDINAL_POSITION` BIGINT NOT NULL,
   `COLUMN_DEFAULT` VARCHAR(256) DEFAULT NULL,
-  `IS_NULLABLE` VARCHAR(5) NOT NULL,
+  `IS_NULLABLE` BOOLEAN NOT NULL,
   `DATA_TYPE` VARCHAR(256) NOT NULL,
   `CHARACTER_MAXIMUM_LENGTH` BIGINT DEFAULT NULL,
   `CHARACTER_OCTET_LENGTH` BIGINT DEFAULT NULL,
@@ -108,8 +108,8 @@
   `DOMAIN_CATALOG` VARCHAR(256) NOT NULL,
   `DOMAIN_SCHEMA` VARCHAR(256) NOT NULL,
   `DOMAIN_NAME` VARCHAR(256) NOT NULL,
-  `IS_DEFERRABLE` VARCHAR(5) NOT NULL,
-  `INITIALLY_DEFERRED` VARCHAR(5) NOT NULL
+  `IS_DEFERRABLE` BOOLEAN NOT NULL,
+  `INITIALLY_DEFERRED` BOOLEAN NOT NULL
 ) ENGINE=FunctionEngine COLLATE = utf8_general_ci
 SHOW CREATE TABLE `KEY_COLUMN_USAGE`;
 Table	Create Table
@@ -282,8 +282,8 @@
   `TABLE_SCHEMA` VARCHAR(256) NOT NULL,
   `TABLE_NAME` VARCHAR(256) NOT NULL,
   `CONSTRAINT_TYPE` VARCHAR(256) NOT NULL,
-  `IS_DEFERRABLE` VARCHAR(5) NOT NULL,
-  `INITIALLY_DEFERRED` VARCHAR(5) NOT NULL
+  `IS_DEFERRABLE` BOOLEAN NOT NULL,
+  `INITIALLY_DEFERRED` BOOLEAN NOT NULL
 ) ENGINE=FunctionEngine COLLATE = utf8_general_ci
 SHOW CREATE TABLE `TABLE_PRIVILEGES`;
 Table	Create Table

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2010-12-24 07:15:43 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2010-12-24 16:11:53 +0000
@@ -3863,6 +3863,7 @@
     return(DATA_DOUBLE);
   case DRIZZLE_TYPE_BLOB:
     return(DATA_BLOB);
+  case DRIZZLE_TYPE_BOOLEAN:
   case DRIZZLE_TYPE_UUID:
     return(DATA_FIXBINARY);
   case DRIZZLE_TYPE_NULL:

=== modified file 'plugin/mysql_protocol/mysql_protocol.cc'
--- plugin/mysql_protocol/mysql_protocol.cc	2010-12-22 19:43:00 +0000
+++ plugin/mysql_protocol/mysql_protocol.cc	2010-12-24 06:48:40 +0000
@@ -547,6 +547,10 @@
         pos[6]= 15;
         break;
 
+      case DRIZZLE_TYPE_BOOLEAN:
+        pos[6]= 15;
+        break;
+
       case DRIZZLE_TYPE_DECIMAL:
         pos[6]= (char)246;
         break;

=== modified file 'plugin/registry_dictionary/tests/r/data_dictionary.result'
--- plugin/registry_dictionary/tests/r/data_dictionary.result	2010-09-02 18:35:05 +0000
+++ plugin/registry_dictionary/tests/r/data_dictionary.result	2010-12-24 08:41:24 +0000
@@ -11,7 +11,7 @@
   `MODULE_NAME` VARCHAR(256) NOT NULL,
   `MODULE_VERSION` VARCHAR(20) NOT NULL,
   `MODULE_AUTHOR` VARCHAR(256) NOT NULL,
-  `IS_BUILTIN` VARCHAR(5) NOT NULL,
+  `IS_BUILTIN` BOOLEAN NOT NULL,
   `MODULE_LIBRARY` VARCHAR(254) NOT NULL,
   `MODULE_DESCRIPTION` VARCHAR(254) NOT NULL,
   `MODULE_LICENSE` VARCHAR(80) NOT NULL
@@ -21,6 +21,6 @@
 PLUGINS	CREATE TABLE `PLUGINS` (
   `PLUGIN_NAME` VARCHAR(256) NOT NULL,
   `PLUGIN_TYPE` VARCHAR(256) NOT NULL,
-  `IS_ACTIVE` VARCHAR(5) NOT NULL,
+  `IS_ACTIVE` BOOLEAN NOT NULL,
   `MODULE_NAME` VARCHAR(256) NOT NULL
 ) ENGINE=FunctionEngine COLLATE = utf8_general_ci

=== modified file 'plugin/schema_dictionary/tests/r/data_dictionary.result'
--- plugin/schema_dictionary/tests/r/data_dictionary.result	2010-12-20 16:56:48 +0000
+++ plugin/schema_dictionary/tests/r/data_dictionary.result	2010-12-24 08:41:24 +0000
@@ -583,16 +583,16 @@
   `COLUMN_TYPE` VARCHAR(256) NOT NULL,
   `ORDINAL_POSITION` BIGINT NOT NULL,
   `COLUMN_DEFAULT` VARBINARY(65535) DEFAULT NULL,
-  `COLUMN_DEFAULT_IS_NULL` VARCHAR(5) NOT NULL,
+  `COLUMN_DEFAULT_IS_NULL` BOOLEAN NOT NULL,
   `COLUMN_DEFAULT_UPDATE` VARCHAR(256) NOT NULL,
-  `IS_SIGNED` VARCHAR(5) DEFAULT NULL,
-  `IS_AUTO_INCREMENT` VARCHAR(5) NOT NULL,
-  `IS_NULLABLE` VARCHAR(5) NOT NULL,
-  `IS_INDEXED` VARCHAR(5) NOT NULL,
-  `IS_USED_IN_PRIMARY` VARCHAR(5) NOT NULL,
-  `IS_UNIQUE` VARCHAR(5) NOT NULL,
-  `IS_MULTI` VARCHAR(5) NOT NULL,
-  `IS_FIRST_IN_MULTI` VARCHAR(5) NOT NULL,
+  `IS_SIGNED` BOOLEAN DEFAULT NULL,
+  `IS_AUTO_INCREMENT` BOOLEAN NOT NULL,
+  `IS_NULLABLE` BOOLEAN NOT NULL,
+  `IS_INDEXED` BOOLEAN NOT NULL,
+  `IS_USED_IN_PRIMARY` BOOLEAN NOT NULL,
+  `IS_UNIQUE` BOOLEAN NOT NULL,
+  `IS_MULTI` BOOLEAN NOT NULL,
+  `IS_FIRST_IN_MULTI` BOOLEAN NOT NULL,
   `INDEXES_FOUND_IN` BIGINT NOT NULL,
   `DATA_TYPE` VARCHAR(256) NOT NULL,
   `DATA_ARCHETYPE` VARCHAR(256) NOT NULL,
@@ -610,9 +610,9 @@
   `TABLE_SCHEMA` VARCHAR(256) NOT NULL,
   `TABLE_NAME` VARCHAR(256) NOT NULL,
   `INDEX_NAME` VARCHAR(256) NOT NULL,
-  `IS_USED_IN_PRIMARY` VARCHAR(5) NOT NULL,
-  `IS_UNIQUE` VARCHAR(5) NOT NULL,
-  `IS_NULLABLE` VARCHAR(5) NOT NULL,
+  `IS_USED_IN_PRIMARY` BOOLEAN NOT NULL,
+  `IS_UNIQUE` BOOLEAN NOT NULL,
+  `IS_NULLABLE` BOOLEAN NOT NULL,
   `KEY_LENGTH` BIGINT NOT NULL,
   `INDEX_TYPE` VARCHAR(256) NOT NULL,
   `INDEX_COMMENT` VARCHAR(1024) DEFAULT NULL
@@ -627,10 +627,10 @@
   `COLUMN_NUMBER` BIGINT NOT NULL,
   `SEQUENCE_IN_INDEX` BIGINT NOT NULL,
   `COMPARE_LENGTH` BIGINT DEFAULT NULL,
-  `IS_ORDER_REVERSE` VARCHAR(5) NOT NULL,
-  `IS_USED_IN_PRIMARY` VARCHAR(5) NOT NULL,
-  `IS_UNIQUE` VARCHAR(5) NOT NULL,
-  `IS_NULLABLE` VARCHAR(5) NOT NULL
+  `IS_ORDER_REVERSE` BOOLEAN NOT NULL,
+  `IS_USED_IN_PRIMARY` BOOLEAN NOT NULL,
+  `IS_UNIQUE` BOOLEAN NOT NULL,
+  `IS_NULLABLE` BOOLEAN NOT NULL
 ) ENGINE=FunctionEngine COLLATE = utf8_general_ci
 show create table REFERENTIAL_CONSTRAINTS ;
 Table	Create Table

=== modified file 'plugin/session_dictionary/tests/r/data_dictionary.result'
--- plugin/session_dictionary/tests/r/data_dictionary.result	2010-12-20 19:20:57 +0000
+++ plugin/session_dictionary/tests/r/data_dictionary.result	2010-12-24 08:41:24 +0000
@@ -10,7 +10,7 @@
   `TIME` BIGINT UNSIGNED NOT NULL,
   `STATE` VARCHAR(256) DEFAULT NULL,
   `INFO` VARCHAR(100) DEFAULT NULL,
-  `HAS_GLOBAL_LOCK` VARCHAR(5) NOT NULL
+  `HAS_GLOBAL_LOCK` BOOLEAN NOT NULL
 ) ENGINE=FunctionEngine COLLATE = utf8_general_ci
 SELECT ID FROM processlist;
 ID

=== modified file 'plugin/table_cache_dictionary/tests/r/table_cache.result'
--- plugin/table_cache_dictionary/tests/r/table_cache.result	2010-11-18 20:42:02 +0000
+++ plugin/table_cache_dictionary/tests/r/table_cache.result	2010-12-24 08:41:24 +0000
@@ -5,7 +5,7 @@
   `TABLE_SCHEMA` VARCHAR(256) NOT NULL,
   `TABLE_NAME` VARCHAR(256) NOT NULL,
   `VERSION` BIGINT NOT NULL,
-  `IS_NAME_LOCKED` VARCHAR(5) NOT NULL,
+  `IS_NAME_LOCKED` BOOLEAN NOT NULL,
   `ROWS` BIGINT NOT NULL,
   `AVG_ROW_LENGTH` BIGINT NOT NULL,
   `TABLE_SIZE` BIGINT NOT NULL,
@@ -17,14 +17,14 @@
 flush tables;
 select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME;
 SESSION_ID	TABLE_SCHEMA	TABLE_NAME	VERSION	IS_NAME_LOCKED	ROWS	AVG_ROW_LENGTH	TABLE_SIZE	AUTO_INCREMENT
-#	data_dictionary	table_cache	#	#	#	2131	#	#
+#	data_dictionary	table_cache	#	#	#	2111	#	#
 create table a ( a int);
 create table b ( b int);
 select * FROM a,b;
 a	b
 select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME;
 SESSION_ID	TABLE_SCHEMA	TABLE_NAME	VERSION	IS_NAME_LOCKED	ROWS	AVG_ROW_LENGTH	TABLE_SIZE	AUTO_INCREMENT
-#	data_dictionary	table_cache	#	#	#	2131	#	#
+#	data_dictionary	table_cache	#	#	#	2111	#	#
 #	test	a	#	#	#	6	#	#
 #	test	b	#	#	#	6	#	#
 DROP TABLES a,b;

=== modified file 'plugin/table_cache_dictionary/tests/r/table_definition_cache.result'
--- plugin/table_cache_dictionary/tests/r/table_definition_cache.result	2010-11-18 20:42:02 +0000
+++ plugin/table_cache_dictionary/tests/r/table_definition_cache.result	2010-12-24 08:41:24 +0000
@@ -5,7 +5,7 @@
   `TABLE_NAME` VARCHAR(256) NOT NULL,
   `VERSION` BIGINT NOT NULL,
   `TABLE_COUNT` BIGINT NOT NULL,
-  `IS_NAME_LOCKED` VARCHAR(5) NOT NULL
+  `IS_NAME_LOCKED` BOOLEAN NOT NULL
 ) ENGINE=FunctionEngine COLLATE = utf8_general_ci
 select count(*) FROM data_dictionary.TABLE_DEFINITION_CACHE;
 count(*)

=== modified file 'tests/r/create.result'
--- tests/r/create.result	2010-12-23 22:20:46 +0000
+++ tests/r/create.result	2010-12-24 16:11:53 +0000
@@ -1473,7 +1473,7 @@
   `TIME` BIGINT UNSIGNED NOT NULL,
   `STATE` VARCHAR(256) DEFAULT NULL,
   `INFO` VARCHAR(100) DEFAULT NULL,
-  `HAS_GLOBAL_LOCK` VARCHAR(5) NOT NULL
+  `HAS_GLOBAL_LOCK` BOOLEAN NOT NULL
 ) ENGINE=InnoDB COLLATE = utf8_general_ci
 drop table t1;
 create temporary table t1 like data_dictionary.processlist;
@@ -1490,7 +1490,7 @@
   `TIME` BIGINT UNSIGNED NOT NULL,
   `STATE` VARCHAR(256) DEFAULT NULL,
   `INFO` VARCHAR(100) DEFAULT NULL,
-  `HAS_GLOBAL_LOCK` VARCHAR(5) NOT NULL
+  `HAS_GLOBAL_LOCK` BOOLEAN NOT NULL
 ) ENGINE=MyISAM COLLATE = utf8_general_ci
 drop table t1;
 

=== modified file 'tests/r/show_check.result'
--- tests/r/show_check.result	2010-11-18 20:42:02 +0000
+++ tests/r/show_check.result	2010-12-24 08:41:24 +0000
@@ -27,7 +27,7 @@
 show index from t1;
 Catalog	Database	Table	Table_alias	Column	Column_alias	Type	Length	Max length	Is_null	Flags	Decimals	Charsetnr
 def	data_dictionary	show_indexes	SHOW_INDEXES	Table	Table	8	1024	2	N	4097	0	45
-def	data_dictionary	show_indexes	SHOW_INDEXES	Unique	Unique	8	20	3	N	4097	0	45
+def	data_dictionary	show_indexes	SHOW_INDEXES	Unique	Unique	8	1	3	N	4097	0	63
 def	data_dictionary	show_indexes	SHOW_INDEXES	Key_name	Key_name	8	1024	7	N	4097	0	45
 def	data_dictionary	show_indexes	SHOW_INDEXES	Seq_in_index	Seq_in_index	5	20	1	N	36865	0	63
 def	data_dictionary	show_indexes	SHOW_INDEXES	Column_name	Column_name	8	1024	1	N	4097	0	45
@@ -447,7 +447,7 @@
 show index from t1;
 Catalog	Database	Table	Table_alias	Column	Column_alias	Type	Length	Max length	Is_null	Flags	Decimals	Charsetnr
 def	data_dictionary	show_indexes	SHOW_INDEXES	Table	Table	8	1024	2	N	4097	0	45
-def	data_dictionary	show_indexes	SHOW_INDEXES	Unique	Unique	8	20	3	N	4097	0	45
+def	data_dictionary	show_indexes	SHOW_INDEXES	Unique	Unique	8	1	3	N	4097	0	63
 def	data_dictionary	show_indexes	SHOW_INDEXES	Key_name	Key_name	8	1024	7	N	4097	0	45
 def	data_dictionary	show_indexes	SHOW_INDEXES	Seq_in_index	Seq_in_index	5	20	1	N	36865	0	63
 def	data_dictionary	show_indexes	SHOW_INDEXES	Column_name	Column_name	8	1024	6	N	4097	0	45

=== added directory 'tests/suite/bool_type'
=== added directory 'tests/suite/bool_type/r'
=== added file 'tests/suite/bool_type/r/basic.result'
--- tests/suite/bool_type/r/basic.result	1970-01-01 00:00:00 +0000
+++ tests/suite/bool_type/r/basic.result	2010-12-24 06:48:40 +0000
@@ -0,0 +1,30 @@
+CREATE TABLE t1 (A BOOLEAN);
+insert into t1 VALUES ("no");
+insert into t1 VALUES ("false");
+insert into t1 VALUES ("true");
+insert into t1 VALUES ("yes");
+insert into t1 VALUES ("NO");
+insert into t1 VALUES ("FALSE");
+insert into t1 VALUES ("TRUE");
+insert into t1 VALUES ("YES");
+insert into t1 VALUES ("n");
+insert into t1 VALUES ("f");
+insert into t1 VALUES ("t");
+insert into t1 VALUES ("y");
+insert into t1 VALUES ("from");
+ERROR HY000: Received an invalid bool value 'from'.
+SELECT A from t1 ORDER BY a;
+A
+FALSE
+FALSE
+FALSE
+FALSE
+FALSE
+FALSE
+TRUE
+TRUE
+TRUE
+TRUE
+TRUE
+TRUE
+DROP TABLE t1;

=== added file 'tests/suite/bool_type/r/primary_key.result'
--- tests/suite/bool_type/r/primary_key.result	1970-01-01 00:00:00 +0000
+++ tests/suite/bool_type/r/primary_key.result	2010-12-24 06:48:40 +0000
@@ -0,0 +1,14 @@
+CREATE TABLE t1 (A BOOLEAN, PRIMARY KEY (A));
+insert into t1 VALUES ("no");
+insert into t1 VALUES ("true");
+insert into t1 VALUES ("true");
+Got one of the listed errors
+SELECT A from t1 ORDER BY a ASC;
+A
+FALSE
+TRUE
+SELECT A from t1 ORDER BY a DESC;
+A
+TRUE
+FALSE
+DROP TABLE t1;

=== added directory 'tests/suite/bool_type/t'
=== added file 'tests/suite/bool_type/t/basic.test'
--- tests/suite/bool_type/t/basic.test	1970-01-01 00:00:00 +0000
+++ tests/suite/bool_type/t/basic.test	2010-12-24 06:48:40 +0000
@@ -0,0 +1,25 @@
+CREATE TABLE t1 (A BOOLEAN);
+insert into t1 VALUES ("no");
+insert into t1 VALUES ("false");
+
+insert into t1 VALUES ("true");
+insert into t1 VALUES ("yes");
+
+insert into t1 VALUES ("NO");
+insert into t1 VALUES ("FALSE");
+
+insert into t1 VALUES ("TRUE");
+insert into t1 VALUES ("YES");
+
+insert into t1 VALUES ("n");
+insert into t1 VALUES ("f");
+
+insert into t1 VALUES ("t");
+insert into t1 VALUES ("y");
+
+--error ER_INVALID_BOOLEAN_VALUE
+insert into t1 VALUES ("from");
+
+SELECT A from t1 ORDER BY a;
+
+DROP TABLE t1;

=== added file 'tests/suite/bool_type/t/primary_key.test'
--- tests/suite/bool_type/t/primary_key.test	1970-01-01 00:00:00 +0000
+++ tests/suite/bool_type/t/primary_key.test	2010-12-24 06:48:40 +0000
@@ -0,0 +1,11 @@
+CREATE TABLE t1 (A BOOLEAN, PRIMARY KEY (A));
+insert into t1 VALUES ("no");
+insert into t1 VALUES ("true");
+
+--error ER_DUP_ENTRY_WITH_KEY_NAME,ER_DUP_ENTRY
+insert into t1 VALUES ("true");
+
+SELECT A from t1 ORDER BY a ASC;
+SELECT A from t1 ORDER BY a DESC;
+
+DROP TABLE t1;

